// Copyright (C) 2005-2007 CEREA
//     Author(s): Lin Wu, Vivien Mallet
//
// CEREA (http://www.enpc.fr/cerea/) is a joint laboratory of ENPC
// (http://www.enpc.fr/) and EDF R&D (http://www.edf.fr/).
//
// This file is part of the air quality modeling system Polyphemus.
//
// Polyphemus is free software; you can redistribute it and/or modify it under
// the terms of the GNU General Public License as published by the Free
// Software Foundation; either version 2 of the License, or (at your option)
// any later version.
//
// Polyphemus is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
// more details.
//
// For more information, please see the Polyphemus web site:
//     http://www.enpc.fr/cerea/polyphemus/


#ifndef POLYPHEMUS_FILE_DRIVER_FOURDIMVARDRIVER_HXX


#include "Trajectory.cxx"
#include "VariationalDriver.cxx"
#include "Bfgs.cxx"
#include <map>


namespace Polyphemus
{


  //////////////////////
  // FOURDIMVARDRIVER //
  //////////////////////


  //! This driver performs 4D-Var.
  template<class T, class ClassModel, class ClassOutputSaver,
	   class ClassObsManager>
  class FourDimVarDriver:
    public VariationalDriver<T, ClassModel, ClassOutputSaver, ClassObsManager>
  {

  protected:

    //! Display precision for sensitivity checking results.
    int display_precision;
    //! With trajectory managements?
    bool with_trajectory_management;

    //! Trajectory manager.
    Trajectory<double, 4> TrajManager;
    //! Trajectory time step in seconds.
    T Trajectory_delta_t;
    //! Trajectory number of time steps.
    string Trajectory_file_name;
    //! Data array that stores trajectories.
    Data<T, 5> TrajData;

    //! Pointer to optimization solver.
    BaseOptimizer* Optimizer;
    //! Type of optimization solver.
    string type;
    //! Maximal iteration for optimization solver.
    int max_iter;
    //! Display iterations during optimizing?
    bool disp_iter;

    //! Name of the file that saves Jb values during optimization.
    string Jb_file;
    //! Name of the file that saves Jo values during optimization.
    string Jo_file;
    //! Name of the file that saves gradient norms during optimization.
    string grad_norm_file;

    //! Temporary debug variable.
    int Ndim;
    bool is_reduced_state;
    bool is_zero_departure;

  public:

    /*** Constructor and destructor ***/

    FourDimVarDriver(string config_file);
    virtual ~FourDimVarDriver();

    /*** Configuration ***/

    virtual void ReadConfiguration();
    
    /*** Initialization ***/

    virtual void Init();

    /*** Methods ***/

    virtual void Run();

  };


} // namespace Polyphemus.


#define POLYPHEMUS_FILE_DRIVER_FOURDIMVARDRIVER_HXX
#endif
