C-----------------------------------------------------------------------
C     Copyright (C) 2003-2007 CEREA
C     Author(s): Edouard Debry
C
C     CEREA (http://www.enpc.fr/cerea/) is a joint laboratory of ENPC
C     (http://www.enpc.fr/) and EDF R&D (http://www.edf.fr/).
C
C     This file is part of the Size Resolved Aerosol Model (SIREAM),
C     which is a component of the air quality modeling system Polyphemus.
C
C     Polyphemus is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
C
C     For more information, please see the Polyphemus web site:
C            http://www.enpc.fr/cerea/polyphemus/
C-----------------------------------------------------------------------

      SUBROUTINE INITPOINT(nbin_aer,iq)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This subroutine performs the initialization of all the pointers
C     related to the Q(*) vector at current time.     
C     All the variables are in common blocks.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C
C     nbin_aer: number of aerosol bins.
C     iq: index of aerosol species in q(*) vector.  
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C     2005/3/23: cleaning (Bruno Sportisse, CEREA).
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     2004: Edouard Debry, CEREA.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

      INCLUDE 'param.inc'
      INCLUDE 'pointer.inc'
      INCLUDE 'dynaero.inc'
      INCLUDE 'varq.inc'
      INCLUDE 'varp.inc'

      INTEGER nbin_aer,iq(NEXT,nbin_aer)
      INTEGER jesp,js,icpt

C     Species to be computed

      E1=EMD
      E2=MAX0(IORG*EPOA,ECl)
      G1=ESO4
      G2=MAX0(IORG*ELIM2,ECl)

C     Pointer for concentrations

      icpt=nbin_aer

                                ! pointer of species at equilibrium
      DO jesp=E1,E2
         DO js=1,ICUT
            icpt=icpt+1
            IQ(jesp,js)=icpt
         END DO
      END DO

                                ! pointer of dynamic species
      DO jesp=E1,E2
         DO js=ICUT+1,nbin_aer
            icpt=icpt+1
            IQ(jesp,js)=icpt
         END DO
      END DO
      
                                ! H2O pointers
      DO js=1,nbin_aer
         icpt=icpt+1
         IQ(EH2O,js)=icpt
      END DO
      
                                ! IQ1 first aero conc
                                ! IQ2 last  aero conc
      IQ1=nbin_aer+1
      IQ2=IQ(E2,nbin_aer)

C     Pointer for gas-phase concentration

      DO jesp=1,NEXT
         icpt=icpt+1
         IG(jesp)=icpt
      END DO

      IG1=IG(1)

C     Pointers related to the Jacobian matrix.

      G12=MAX0(G1,ENH3)

      END
