// Copyright (C) 2007 CEREA
//     Author(s): Vivien Mallet
//
// CEREA (http://www.enpc.fr/cerea/) is a joint laboratory of ENPC
// (http://www.enpc.fr/) and EDF R&D (http://www.edf.fr/).
//
// This file is part of the air quality modeling system Polyphemus.
//
// Polyphemus is free software; you can redistribute it and/or modify it under
// the terms of the GNU General Public License as published by the Free
// Software Foundation; either version 2 of the License, or (at your option)
// any later version.
//
// Polyphemus is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
// more details.
//
// For more information, please see the Polyphemus web site:
//     http://www.enpc.fr/cerea/polyphemus/


#ifndef POLYPHEMUS_FILE_MODULES_COMMON_BASEMODULE_CXX


#include "BaseModule.hxx"


namespace Polyphemus
{


  //! Initialization of the module.
  /*! \note Empty method.
   */
  template<class T>
  void BaseModule::Init(BaseModel<T>& Model)
  {
    throw "\"BaseModule::Init(BaseModel<T>& Model)\" is undefined.";
  }


  //! Performs an integration over one time step.
  /*!
    \note Empty method.
  */
  template<class T>
  void BaseModule::Forward(BaseModel<T>& Model)
  {
    throw "\"BaseModule::Forward(BaseModel<T>& Model)\" is undefined.";
  }


  //! Performs an integration over one time step for aerosols.
  /*!
    \note Empty method.
  */
  template<class T>
  void BaseModule::Forward_aer(BaseModel<T>& Model)
  {
    throw "\"BaseModule::Forward_aer(BaseModel<T>& Model)\" is undefined.";
  }


  //! Performs one step of backward integration of adjoint model.
  /*!
    \note Empty method.
  */
  template<class T>
  void BaseModule::Backward(BaseModel<T>& Model)
  {
    throw "\"BaseModule::Backward(BaseModel<T>& Model)\" is undefined.";
  }


} // namespace Polyphemus.


#define POLYPHEMUS_FILE_MODULES_COMMON_BASEMODULE_CXX
#endif
